@@ -10,20 +10,30 @@ use crate::handlers::{
 use crate::parsers::*;
 use crate::plugins::*;
 use crate::{App, Backend, BackendSystem, FrameState, GfxExtension, GfxRenderer};
+use indexmap::IndexMap;
 #[cfg(feature = "audio")]
 use notan_audio::Audio;
+use notan_core::events::{Event, EventIterator};
+use notan_core::mouse::MouseButton;
+use notan_input::internals::{
+    clear_keyboard, clear_mouse, process_keyboard_events, process_mouse_events,
+    process_touch_events,
+};
 
 pub use crate::handlers::SetupHandler;
 
-//TODO read this https://floooh.github.io/2017/05/15/oryol-spirv.html
-
 /// Configurations used at build time
 pub trait BuildConfig<S, B>
 where
     B: Backend,
 {
     /// Applies the configuration on the builder
-    fn apply(self, builder: AppBuilder<S, B>) -> AppBuilder<S, B>;
+    fn apply(&self, builder: AppBuilder<S, B>) -> AppBuilder<S, B>;
+
+    /// This config will be applied before the app is initiated not when is set
+    fn late_evaluation(&self) -> bool {
+        false
+    }
 }
 
 /// The builder is charge of create and configure the application
@@ -42,6 +52,10 @@ pub struct AppBuilder<S, B> {
     plugin_callbacks: Vec<Box<dyn FnOnce(&mut App, &mut Assets, &mut Graphics, &mut Plugins)>>,
     extension_callbacks: Vec<Box<dyn FnOnce(&mut App, &mut Assets, &mut Graphics, &mut Plugins)>>,
 
+    late_config: Option<IndexMap<std::any::TypeId, Box<dyn BuildConfig<S, B>>>>,
+
+    use_touch_as_mouse: bool,
+
     pub(crate) window: WindowConfig,
 }
 
@@ -67,28 +81,46 @@ where
             plugin_callbacks: vec![],
             extension_callbacks: vec![],
             window: Default::default(),
+            late_config: Some(Default::default()),
+            use_touch_as_mouse: true,
         };
 
         builder.default_loaders()
     }
 
-    pub fn default_loaders(self) -> Self {
-        let mut s = self.add_loader(create_texture_parser());
+    #[allow(unreachable_code)]
+    fn default_loaders(self) -> Self {
+        let s = self.add_loader(create_texture_parser());
 
         #[cfg(feature = "audio")]
         {
-            s = s.add_loader(create_audio_parser());
+            return s.add_loader(create_audio_parser());
         }
 
         s
     }
 
+    /// Converts touch events as mouse events
+    pub fn touch_as_mouse(mut self, enabled: bool) -> Self {
+        self.use_touch_as_mouse = enabled;
+        self
+    }
+
     /// Applies a configuration
-    pub fn add_config<C>(self, config: C) -> Self
+    pub fn add_config<C>(mut self, config: C) -> Self
     where
-        C: BuildConfig<S, B>,
+        C: BuildConfig<S, B> + 'static,
     {
-        config.apply(self)
+        if config.late_evaluation() {
+            if let Some(late_config) = &mut self.late_config {
+                let typ = std::any::TypeId::of::<C>();
+                late_config.insert(typ, Box::new(config));
+            }
+
+            self
+        } else {
+            config.apply(self)
+        }
     }
 
     /// Sets a callback used before the application loop starts running
@@ -173,6 +205,13 @@ where
 
     /// Creates and run the application
     pub fn build(self) -> Result<(), String> {
+        let mut builder = self;
+        if let Some(late_config) = builder.late_config.take() {
+            for (_, config) in late_config {
+                builder = config.apply(builder);
+            }
+        }
+
         let AppBuilder {
             mut backend,
             setup_callback,
@@ -186,8 +225,9 @@ where
             mut plugin_callbacks,
             mut extension_callbacks,
             window,
+            use_touch_as_mouse,
             ..
-        } = self;
+        } = builder;
 
         // let load_file = backend.get_file_loader();
         let initialize = backend.initialize(window)?;
@@ -236,6 +276,8 @@ where
             cb.exec(&mut app, &mut assets, &mut plugins, &mut state);
         }
 
+        let mut current_touch_id: Option<u64> = None;
+
         if let Err(e) = initialize(app, state, move |app, mut state| {
             let win_size = app.window().size();
             if graphics.size() != win_size {
@@ -261,10 +303,18 @@ where
 
             assets.tick((app, &mut graphics, &mut plugins, &mut state))?;
 
+            let delta = app.timer.delta_f32();
+
             // Manage each event
-            for evt in app.backend.events_iter() {
-                app.keyboard.process_events(&evt, app.timer.delta_f32());
-                app.mouse.process_events(&evt, app.timer.delta_f32());
+            let mut events = app.backend.events_iter();
+            while let Some(evt) = events.next() {
+                if use_touch_as_mouse {
+                    touch_as_mouse(&mut current_touch_id, &mut events, &evt);
+                }
+
+                process_keyboard_events(&mut app.keyboard, &evt, delta);
+                process_mouse_events(&mut app.mouse, &evt, delta);
+                process_touch_events(&mut app.touch, &evt, delta);
 
                 match plugins.event(app, &mut assets, &evt)? {
                     AppFlow::Skip => {}
@@ -308,8 +358,8 @@ where
                 }
             }
 
-            app.mouse.clear();
-            app.keyboard.clear();
+            clear_mouse(&mut app.mouse);
+            clear_keyboard(&mut app.keyboard);
 
             // Manage post frame event
             let _ = plugins.post_frame(app, &mut assets, &mut graphics)?;
@@ -331,3 +381,54 @@ where
         Ok(())
     }
 }
+
+#[inline]
+fn touch_as_mouse(current_touch_id: &mut Option<u64>, events: &mut EventIterator, evt: &Event) {
+    match evt {
+        Event::TouchStart { id, x, y } => {
+            if current_touch_id.is_none() || current_touch_id.unwrap() == *id {
+                *current_touch_id = Some(*id);
+                events.push_front(Event::MouseDown {
+                    button: MouseButton::Left,
+                    x: *x as _,
+                    y: *y as _,
+                });
+            }
+        }
+        Event::TouchMove { id, x, y } => {
+            if let Some(last_id) = current_touch_id {
+                if last_id == id {
+                    events.push_front(Event::MouseMove {
+                        x: *x as _,
+                        y: *y as _,
+                    });
+                }
+            }
+        }
+        Event::TouchEnd { id, x, y } => {
+            if let Some(last_id) = current_touch_id {
+                if last_id == id {
+                    *current_touch_id = None;
+                    events.push_front(Event::MouseUp {
+                        button: MouseButton::Left,
+                        x: *x as _,
+                        y: *y as _,
+                    });
+                }
+            }
+        }
+        Event::TouchCancel { id, x, y } => {
+            if let Some(last_id) = current_touch_id {
+                if last_id == id {
+                    *current_touch_id = None;
+                    events.push_front(Event::MouseUp {
+                        button: MouseButton::Left,
+                        x: *x as _,
+                        y: *y as _,
+                    });
+                }
+            }
+        }
+        _ => {}
+    }
+}
